shithub: libvpx

Download patch

ref: f0ccdb19f44e2549415fc24b7cc39fa882f5b565
parent: 17b2ce11aca791e3fcdb85cc391d5aa9196ef633
author: Marco Paniconi <marpan@google.com>
date: Thu Jun 18 07:24:28 EDT 2020

vp9-rtc: Fix to resetting drop_spatial_layer

The reset happens on the base spatial layer, before
encoding. But it should be reset on the
first_spatial_layer_to_encode, which may not be 0.

Change-Id: I38ef686b4459ca7433062adbfe32ef2134e1ad60
(cherry picked from commit 769129fb29fc66720be2b01276a472c334757d2d)

--- a/vp9/encoder/vp9_svc_layercontext.c
+++ b/vp9/encoder/vp9_svc_layercontext.c
@@ -864,8 +864,9 @@
     }
   }
 
-  // Reset the drop flags for all spatial layers, on the base layer.
-  if (svc->spatial_layer_id == 0) {
+  // Reset the drop flags for all spatial layers, on the
+  // first_spatial_layer_to_encode.
+  if (svc->spatial_layer_id == svc->first_spatial_layer_to_encode) {
     vp9_zero(svc->drop_spatial_layer);
     // TODO(jianj/marpan): Investigate why setting svc->lst/gld/alt_fb_idx
     // causes an issue with frame dropping and temporal layers, when the frame